@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: ardour_ui.cc,v 1.263 2006/02/19 02:09:56 essej Exp $
+    $Id: ardour_ui.cc,v 1.265 2006/03/29 20:41:22 essej Exp $
 */
 
 #include <algorithm>
@@ -173,7 +173,6 @@ ARDOUR_UI::ARDOUR_UI (int *argcp, char **argvp[], string rcfile)
 	option_editor = 0;
 	location_ui = 0;
 	sfdb_window = 0;
-	new_session_window = 0;
 	open_session_selector = 0;
 	have_configure_timeout = false;
 	have_disk_overrun_displayed = false;
@@ -1401,7 +1400,7 @@ ARDOUR_UI::transport_record ()
 			break;
 		case Session::Recording:
 		case Session::Enabled:
-			session->disable_record ();
+			session->disable_record (false);
 		}
 	}
 }
@@ -2060,23 +2059,21 @@ ARDOUR_UI::save_template ()
 void
 ARDOUR_UI::new_session (bool startup, string predetermined_path)
 {
-	if (new_session_window == 0){
-		new_session_window = new NewSessionDialog (*engine, startup, predetermined_path);
-		editor->ensure_float (*new_session_window);
-	}
+	NewSessionDialog new_session_window (*engine, startup, predetermined_path);
+	editor->ensure_float (new_session_window);
 
-	new_session_window->run ();
+	new_session_window.run ();
 
 	/* write favorites either way */
 	Session::FavoriteDirs favs;
-	new_session_window->file_selector.get_favorites (favs);
+	new_session_window.file_selector.get_favorites (favs);
 	Session::write_favorite_dirs (favs);
 
-	if (new_session_window->run_status()) {
+	if (new_session_window.run_status()) {
 		return;
 	}
 
-	string session_path = new_session_window->file_selector.get_path ();
+	string session_path = new_session_window.file_selector.get_path ();
 	string session_name = PBD::basename (session_path);
 
 	// Check that it doesn't already exist.
@@ -2090,7 +2087,7 @@ ARDOUR_UI::new_session (bool startup, string predetermined_path)
 
 	if (session_path[session_path.length()-1] != '/') {
 
-		string template_name = new_session_window->get_template_name ();
+		string template_name = new_session_window.get_template_name ();
 
 		if (template_name.length()) {
 
@@ -2103,33 +2100,33 @@ ARDOUR_UI::new_session (bool startup, string predetermined_path)
 			Session::AutoConnectOption iconnect;
 			Session::AutoConnectOption oconnect;
 
-			if (new_session_window->use_control_button.get_active()) {
-				cchns = (uint32_t) channel_combo_get_channel_count (new_session_window->control_out_channel_combo);
+			if (new_session_window.use_control_button.get_active()) {
+				cchns = (uint32_t) channel_combo_get_channel_count (new_session_window.control_out_channel_combo);
 			} else {
 				cchns = 0;
 			}
-			if (new_session_window->use_master_button.get_active()) {
-				mchns = (uint32_t) channel_combo_get_channel_count (new_session_window->master_out_channel_combo);
+			if (new_session_window.use_master_button.get_active()) {
+				mchns = (uint32_t) channel_combo_get_channel_count (new_session_window.master_out_channel_combo);
 			} else {
 				mchns = 0;
 			}
 
-			if (new_session_window->connect_to_physical_inputs_button.get_active()) {
+			if (new_session_window.connect_to_physical_inputs_button.get_active()) {
 				iconnect = Session::AutoConnectPhysical;
 			} else {
 				iconnect = Session::AutoConnectOption (0);
 			}
 
-			if (new_session_window->connect_to_master_button.get_active ()) {
+			if (new_session_window.connect_to_master_button.get_active ()) {
 				oconnect = Session::AutoConnectMaster;
-			} else if (new_session_window->connect_to_physical_outputs_button.get_active ()) {
+			} else if (new_session_window.connect_to_physical_outputs_button.get_active ()) {
 				oconnect = Session::AutoConnectPhysical;
 			} else {
 				oconnect = Session::AutoConnectOption (0);
 			} 
 
-			uint32_t nphysin = (uint32_t) new_session_window->in_count_adjustment.get_value();
-			uint32_t nphysout = (uint32_t) new_session_window->out_count_adjustment.get_value();
+			uint32_t nphysin = (uint32_t) new_session_window.in_count_adjustment.get_value();
+			uint32_t nphysout = (uint32_t) new_session_window.out_count_adjustment.get_value();
 
 			build_session (session_path, session_name, cchns, mchns, iconnect, oconnect, nphysin, nphysout, 
 				       engine->frame_rate() * 60 * 5);
