@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: ardour_ui.h,v 1.160 2006/01/29 23:25:40 essej Exp $
+    $Id: ardour_ui.h,v 1.161 2006/03/26 16:29:40 taybin Exp $
 */
 
 #ifndef __ardour_gui_h__
@@ -63,7 +63,6 @@ class RouteParams_UI;
 class SoundFileSelector;
 class About;
 class AddRouteDialog;
-class NewSessionDialog;
 class LocationUI;
 
 namespace Gtkmmext {
@@ -546,9 +545,6 @@ class ARDOUR_UI : public Gtkmmext::UI
 
 	bool _will_create_new_session_automatically;
 
-	NewSessionDialog* new_session_window;
-	string template_name;
-
 	void new_session_ok_clicked ();
 	void new_session_template_choice (Gtkmmext::Selector *, Gtkmmext::SelectionResult*);
 	void hide_dialog (ArdourDialog *dialog);
