@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: editor_markers.cc,v 1.31 2005/04/30 16:47:22 pauld Exp $
+    $Id: editor_markers.cc,v 1.32 2006/03/21 18:18:58 sampo Exp $
 */
 
 #include <sigc++/rettype.h>
@@ -769,7 +769,14 @@ Editor::marker_menu_rename ()
 		bool is_start;
 
 		if ((l = find_location_from_marker (marker, is_start)) != 0) {
+
+			begin_reversible_command ( _("rename marker") );
+			session->add_undo( session->locations()->get_memento() );
+
 			l->set_name (entry.get_text());
+
+			session->add_redo_no_execute( session->locations()->get_memento() );
+			commit_reversible_command ();
 		}
 	}
 }
