@@ -936,7 +936,7 @@ process_node (const char *file, const struct stat *sb, int32_t flag)
 
 	SNDFILE *sf;
 	SF_INFO info;
-	if ((sf = sf_open ((char *) file, SFM_READ, &info)) < 0) {
+	if ((sf = sf_open ((char *) file, SFM_READ, &info)) == 0) {
 		error << compose(_("file \"%1\" could not be opened"), file) << endmsg;
 		return ftw_return;
 	}
@@ -1092,7 +1092,7 @@ SoundFileBox::setup_labels (string uri)
 		file = uri;
 	}
 
-	if ((sf = sf_open ((char *) file.c_str(), SFM_READ, sf_info)) < 0) {
+	if ((sf = sf_open ((char *) file.c_str(), SFM_READ, sf_info)) == 0) {
 		error << compose(_("file \"%1\" could not be opened"), file) << endmsg;
 		return -1;
 	}
