@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: session.h,v 1.194 2006/02/14 04:58:40 essej Exp $
+    $Id: session.h,v 1.195 2006/03/29 20:41:25 essej Exp $
 */
 
 #ifndef __ardour_session_h__
@@ -319,7 +319,7 @@ class Session : public SigC::Object, public Stateful
 	
 	bool record_enabling_legal () const;
 	void maybe_enable_record ();
-	void disable_record ();
+	void disable_record (bool rt_context);
 	void step_back_from_record ();
 
 	void maybe_write_autosave ();
