@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: audio_playlist.cc,v 1.40 2006/01/19 08:17:14 essej Exp $
+    $Id: audio_playlist.cc,v 1.44 2006/03/31 21:34:25 sampo Exp $
 */
 
 #include <algorithm>
@@ -72,6 +72,43 @@ AudioPlaylist::AudioPlaylist (const AudioPlaylist& other, string name, bool hidd
 {
 	save_state (_("initial state"));
 
+	list<Region*>::const_iterator in_o  = other.regions.begin();
+	list<Region*>::iterator in_n = regions.begin();
+
+	while (in_o != other.regions.end()) {
+		AudioRegion *ar = dynamic_cast<AudioRegion *>( (*in_o) );
+
+		// We look only for crossfades which begin with the current region, so we don't get doubles
+		for (list<Crossfade *>::const_iterator xfades = other._crossfades.begin(); xfades != other._crossfades.end(); ++xfades) {
+			if ( &(*xfades)->in() == ar) {
+				// We found one! Now copy it!
+
+				list<Region*>::const_iterator out_o = other.regions.begin();
+				list<Region*>::const_iterator out_n = regions.begin();
+
+				while (out_o != other.regions.end()) {
+					
+					AudioRegion *ar2 = dynamic_cast<AudioRegion *>( (*out_o) );
+					
+					if ( &(*xfades)->out() == ar2) {
+						AudioRegion *in  = dynamic_cast<AudioRegion*>( (*in_n) );
+						AudioRegion *out = dynamic_cast<AudioRegion*>( (*out_n) );
+						Crossfade *new_fade = new Crossfade( *(*xfades), in, out);
+						add_crossfade(*new_fade);
+						break;
+					}
+					
+					out_o++;
+					out_n++;
+				}
+//				cerr << "HUH!? second region in the crossfade not found!" << endl;
+			}
+		}
+
+		in_o++;
+		in_n++;
+	}
+
 	if (!hidden) {
 		PlaylistCreated (this); /* EMIT SIGNAL */
 	}
@@ -307,6 +344,46 @@ AudioPlaylist::refresh_dependents (Region& r)
 	}
 }
 
+void
+AudioPlaylist::finalize_split_region (Region *o, Region *l, Region *r)
+{
+	AudioRegion *orig  = dynamic_cast<AudioRegion*>(o);
+	AudioRegion *left  = dynamic_cast<AudioRegion*>(l);
+	AudioRegion *right = dynamic_cast<AudioRegion*>(r);
+
+	for (Crossfades::iterator x = _crossfades.begin(); x != _crossfades.end();) {
+		Crossfades::iterator tmp;
+		tmp = x;
+		++tmp;
+
+		Crossfade *fade = 0;
+		
+		if ((*x)->_in == orig) {
+			if (! (*x)->covers(right->position())) {
+				fade = new Crossfade( *(*x), left, (*x)->_out);
+			} else {
+				// Overlap, the crossfade is copied on the left side of the right region instead
+				fade = new Crossfade( *(*x), right, (*x)->_out);
+			}
+		}
+		
+		if ((*x)->_out == orig) {
+			if (! (*x)->covers(right->position())) {
+				fade = new Crossfade( *(*x), (*x)->_in, right);
+			} else {
+				// Overlap, the crossfade is copied on the right side of the left region instead
+				fade = new Crossfade( *(*x), (*x)->_in, left);
+			}
+		}
+		
+		if (fade) {
+			_crossfades.remove( (*x) );
+			add_crossfade (*fade);
+		}
+		x = tmp;
+	}
+}
+
 void
 AudioPlaylist::check_dependents (Region& r, bool norefresh)
 {
