@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: audioregion.cc,v 1.54 2005/09/10 17:34:25 pauld Exp $
+    $Id: audioregion.cc,v 1.57 2006/04/23 08:50:52 sampo Exp $
 */
 
 #include <cmath>
@@ -78,6 +78,7 @@ AudioRegion::AudioRegion (Source& src, jack_nframes_t start, jack_nframes_t leng
 
 	set_default_fades ();
 	set_default_envelope ();
+
 	save_state ("initial state");
 
 	_envelope.StateChanged.connect (slot (*this, &AudioRegion::envelope_changed));
@@ -165,28 +166,32 @@ AudioRegion::AudioRegion (const AudioRegion& other, jack_nframes_t offset, jack_
 	}
 
 	/* return to default fades if the existing ones are too long */
+	_fade_in_disabled = 0;
+	_fade_out_disabled = 0;
+
 
 	if (_flags & LeftOfSplit) {
 		if (_fade_in.back()->when >= _length) {
 			set_default_fade_in ();
+		} else {
+			_fade_in_disabled = other._fade_in_disabled;
 		}
 		set_default_fade_out ();
-		_flags = Flag (_flags & ~Region::RightOfSplit);
+		_flags = Flag (_flags & ~Region::LeftOfSplit);
 	}
 
 	if (_flags & RightOfSplit) {
 		if (_fade_out.back()->when >= _length) {
 			set_default_fade_out ();
+		} else {
+			_fade_out_disabled = other._fade_out_disabled;
 		}
 		set_default_fade_in ();
-		_flags = Flag (_flags & ~Region::LeftOfSplit);
+		_flags = Flag (_flags & ~Region::RightOfSplit);
 	}
 
 	_scale_amplitude = other._scale_amplitude;
 
-	_fade_in_disabled = 0;
-	_fade_out_disabled = 0;
-
 	save_state ("initial state");
 
 	_envelope.StateChanged.connect (slot (*this, &AudioRegion::envelope_changed));
@@ -646,7 +651,7 @@ AudioRegion::state (bool full)
 	
 	snprintf (buf, sizeof (buf), "0x%x", (int) _flags);
 	node.add_property ("flags", buf);
-	snprintf (buf, sizeof(buf), "%f", _scale_amplitude);
+	snprintf (buf, sizeof(buf), "%.12g", _scale_amplitude);
 	node.add_property ("scale-gain", buf);
 
 	for (uint32_t n=0; n < sources.size(); ++n) {
@@ -719,6 +724,9 @@ AudioRegion::set_state (const XMLNode& node)
 
 	if ((prop = node.property ("flags")) != 0) {
 		_flags = Flag (strtol (prop->value().c_str(), (char **) 0, 16));
+
+		_flags = Flag (_flags & ~Region::LeftOfSplit);
+		_flags = Flag (_flags & ~Region::RightOfSplit);
 	}
 
 	if ((prop = node.property ("scale-gain")) != 0) {
@@ -1275,13 +1283,21 @@ void
 AudioRegion::normalize_to (float target_dB)
 {
 	const jack_nframes_t blocksize = 256 * 1048;
-	Sample buf[blocksize];
+	Sample * buf = 0;
 	jack_nframes_t fpos;
 	jack_nframes_t fend;
 	jack_nframes_t to_read;
-	double maxamp = 0;
+	gain_t maxamp = 0;
 	gain_t target = dB_to_coefficient (target_dB);
 
+	// create properly aligned temp buf
+#ifdef NO_POSIX_MEMALIGN
+	buf = (Sample *) malloc(blocksize * sizeof(Sample));
+#else
+	posix_memalign((void **)&buf, 16, blocksize * 4);
+#endif			
+
+	
 	if (target == 1.0f) {
 		/* do not normalize to precisely 1.0 (0 dBFS), to avoid making it appear
 		   that we may have clipped.
@@ -1305,7 +1321,7 @@ AudioRegion::normalize_to (float target_dB)
 			/* read it in */
 
 			if (source (n).read (buf, fpos, to_read) != to_read) {
-				return;
+				goto cleanup;
 			}
 			
 			maxamp = Session::compute_peak (buf, to_read, maxamp);
@@ -1316,18 +1332,20 @@ AudioRegion::normalize_to (float target_dB)
 
 	if (maxamp == 0.0f) {
 		/* don't even try */
-		return;
+		goto cleanup;
 	}
 
 	if (maxamp == target) {
 		/* we can't do anything useful */
-		return;
+		goto cleanup;
 	}
 
 	/* compute scale factor */
 
 	_scale_amplitude = target/maxamp;
 
+	//fprintf(stderr, "maxamp: %.10g  target: %.10g  eps: %.10g  scale: %0.10g fpos: %lu  fend: %lu\n", maxamp, target, FLT_EPSILON, _scale_amplitude, fpos, fend);
+	
 	if (!_frozen) {
 		char buf[64];
 		snprintf (buf, sizeof (buf), _("normalized to %.2fdB"), target_dB);
@@ -1343,6 +1361,10 @@ AudioRegion::normalize_to (float target_dB)
 	/* tell everybody else */
 
 	send_change (ScaleAmplitudeChanged);
+
+cleanup:
+
+	free(buf);
 }
 
 void
