@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: automation_event.cc,v 1.53 2005/05/05 16:17:12 pauld Exp $
+    $Id: automation_event.cc,v 1.54 2006/04/21 21:16:01 essej Exp $
 */
 
 #include <set>
@@ -1174,7 +1174,7 @@ AutomationList::store_state (XMLNode& node) const
 		
 		snprintf (buf, sizeof (buf), "%" PRIu32, (jack_nframes_t) floor ((*i)->when));
 		pointnode->add_property ("x", buf);
-		snprintf (buf, sizeof (buf), "%f", (*i)->value);
+		snprintf (buf, sizeof (buf), "%.12g", (*i)->value);
 		pointnode->add_property ("y", buf);
 
 		node.add_child_nocopy (*pointnode);
