@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: crossfade.cc,v 1.38 2006/01/19 08:17:14 essej Exp $
+    $Id: crossfade.cc,v 1.41 2006/04/21 21:16:01 essej Exp $
 */
 
 #include <sigc++/bind.h>
@@ -161,6 +161,36 @@ Crossfade::Crossfade (const Playlist& playlist, XMLNode& node)
 	save_state ("initial");
 }
 
+Crossfade::Crossfade (const Crossfade &orig, ARDOUR::AudioRegion *newin, ARDOUR::AudioRegion *newout)
+	: _fade_in(orig._fade_in),
+	  _fade_out(orig._fade_out)
+{
+	_active 			= orig._active;
+	_in_update 			= orig._in_update;
+	_length 			= orig._length;
+	_position 			= orig._position;
+	_anchor_point 		= orig._anchor_point;
+	_follow_overlap 	= orig._follow_overlap;
+	_fixed 				= orig._fixed;
+	_follow_overlap 	= orig._follow_overlap;
+	_short_xfade_length = orig._short_xfade_length;
+	
+	_in = newin;
+	_out = newout;
+
+	// copied from Crossfade::initialize()
+	_in_update = false;
+	
+	_out->suspend_fade_out ();
+	_in->suspend_fade_in ();
+
+	overlap_type = _in->coverage (_out->position(), _out->last_frame());
+
+	// Let's make sure the fade isn't too long
+	set_length(_length);
+}
+
+
 Crossfade::~Crossfade ()
 {
 	for (StateMap::iterator i = states.begin(); i != states.end(); ++i) {
@@ -673,7 +703,7 @@ Crossfade::get_state ()
 
 		snprintf (buf, sizeof (buf), "%" PRIu32, (jack_nframes_t) floor ((*ii)->when));
 		pnode->add_property ("x", buf);
-		snprintf (buf, sizeof (buf), "%f", (*ii)->value);
+		snprintf (buf, sizeof (buf), "%.12g", (*ii)->value);
 		pnode->add_property ("y", buf);
 		child->add_child_nocopy (*pnode);
 	}
@@ -687,7 +717,7 @@ Crossfade::get_state ()
 
 		snprintf (buf, sizeof (buf), "%" PRIu32, (jack_nframes_t) floor ((*ii)->when));
 		pnode->add_property ("x", buf);
-		snprintf (buf, sizeof (buf), "%f", (*ii)->value);
+		snprintf (buf, sizeof (buf), "%.12g", (*ii)->value);
 		pnode->add_property ("y", buf);
 		child->add_child_nocopy (*pnode);
 	}
