@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: filesource.cc,v 1.60 2006/02/01 21:45:17 taybin Exp $
+    $Id: filesource.cc,v 1.61 2006/03/29 18:56:25 essej Exp $
 */
 
 #include <algorithm>
@@ -1202,7 +1202,7 @@ FileSource::repair (string path, jack_nframes_t rate)
 		goto out;
 	}
 	
-	if (memcmp (&buf[0], "RIFF", 4) || memcmp (&buf[8], "WAVE", 4) || memcmp (&buf[0], "RIFX", 4)) {
+	if ((memcmp (&buf[0], "RIFF", 4) && memcmp (&buf[0], "RIFX", 4)) || memcmp (&buf[8], "WAVE", 4)) {
 		/* no header. too dangerous to proceed */
 		goto out;
 	} 
