@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: io.cc,v 1.151 2006/02/20 21:38:37 essej Exp $
+    $Id: io.cc,v 1.152 2006/03/21 16:13:46 essej Exp $
 */
 
 #include <fstream>
@@ -116,7 +116,8 @@ IO::IO (Session& s, string name,
 	_noutputs = 0;
 	no_panner_reset = false;
 	deferred_state = 0;
-
+	deliver_skip_gain = false;
+	
 	_midi_gain_control.midi_to_gain = direct_midi_to_gain;
 	_midi_gain_control.gain_to_midi = direct_gain_to_midi;
 
@@ -416,7 +417,7 @@ IO::deliver_output_no_pan (vector<Sample *>& bufs, uint32_t nbufs, jack_nframes_
 	gain_t dg;
 	gain_t old_gain = 0.0f;
 
-	if (apply_gain_automation) {
+	if (apply_gain_automation || deliver_skip_gain) {
 
 		/* gain has already been applied by automation code. do nothing here except
 		   speed quietning.
@@ -484,7 +485,7 @@ IO::deliver_output_no_pan (vector<Sample *>& bufs, uint32_t nbufs, jack_nframes_
 		_gain = dg;
 	}
 
-	if (apply_gain_automation) {
+	if (apply_gain_automation || deliver_skip_gain) {
 		_gain = old_gain;
 	}
 }
