@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: panner.cc,v 1.47 2006/02/20 21:38:37 essej Exp $
+    $Id: panner.cc,v 1.48 2006/04/21 21:16:02 essej Exp $
 */
 
 #include <cmath>
@@ -678,7 +678,7 @@ EqualPowerStereoPanner::state (bool full_state)
 	char buf[64];
 	LocaleGuard lg (X_("POSIX"));
 
-	snprintf (buf, sizeof (buf), "%f", x); 
+	snprintf (buf, sizeof (buf), "%.12g", x); 
 	root->add_property (X_("x"), buf);
 	root->add_property (X_("type"), EqualPowerStereoPanner::name);
 	if (full_state) {
@@ -912,9 +912,9 @@ Multi2dPanner::state (bool full_state)
 	char buf[64];
 	LocaleGuard lg (X_("POSIX"));
 
-	snprintf (buf, sizeof (buf), "%f", x); 
+	snprintf (buf, sizeof (buf), "%.12g", x); 
 	root->add_property (X_("x"), buf);
-	snprintf (buf, sizeof (buf), "%f", y); 
+	snprintf (buf, sizeof (buf), "%.12g", y); 
 	root->add_property (X_("y"), buf);
 	root->add_property (X_("type"), Multi2dPanner::name);
 
@@ -1360,9 +1360,9 @@ Panner::state (bool full)
 
 	for (vector<Panner::Output>::iterator o = outputs.begin(); o != outputs.end(); ++o) {
 		XMLNode* onode = new XMLNode (X_("Output"));
-		snprintf (buf, sizeof (buf), "%f", (*o).x);
+		snprintf (buf, sizeof (buf), "%.12g", (*o).x);
 		onode->add_property (X_("x"), buf);
-		snprintf (buf, sizeof (buf), "%f", (*o).y);
+		snprintf (buf, sizeof (buf), "%.12g", (*o).y);
 		onode->add_property (X_("y"), buf);
 		root->add_child_nocopy (*onode);
 	}
