@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: playlist.cc,v 1.119 2005/06/28 01:51:18 taybin Exp $
+    $Id: playlist.cc,v 1.124 2006/03/31 22:32:01 sampo Exp $
 */
 
 #include <set>
@@ -98,11 +98,32 @@ Playlist::Playlist (const Playlist& other, string namestr, bool hide)
 {
 	init (hide);
 
-	other.copy_regions (regions);
+	RegionList tmp;
+	other.copy_regions (tmp);
+	
+	in_set_state = true;
 
-	for (list<Region*>::iterator x = regions.begin(); x != regions.end(); ++x) {
-		(*x)->set_playlist (this);
+	for (list<Region*>::iterator x = tmp.begin(); x != tmp.end(); ++x) {
+		add_region_internal( (*x), (*x)->position() );
 	}
+
+	in_set_state = false;
+
+	_splicing  = other._splicing;
+	_nudging   = other._nudging;
+	_edit_mode = other._edit_mode;
+
+	in_set_state = false;
+	in_flush = false;
+	in_partition = false;
+	subcnt = 0;
+	_read_data_count = 0;
+	_frozen = other._frozen;
+	save_on_thaw = false;
+	
+	layer_op_counter = other.layer_op_counter;
+	freeze_length = other.freeze_length;
+	
 }
 
 Playlist::Playlist (const Playlist& other, jack_nframes_t start, jack_nframes_t cnt, string str, bool hide)
@@ -411,8 +432,10 @@ Playlist::flush_notifications ()
 	}
 
 	if (n || pending_modified) {
-		possibly_splice ();
-		relayer ();
+		if (!in_set_state) {
+			possibly_splice ();
+			relayer ();
+		}
 		pending_modified = false;
 		Modified (); /* EMIT SIGNAL */
 	}
@@ -961,10 +984,6 @@ Playlist::split_region (Region& region, jack_nframes_t playlist_position)
 		return;
 	}
 
-	if (remove_region_internal (&region, true)) {
-		return;
-	}
-
 	Region *left;
 	Region *right;
 	jack_nframes_t before;
@@ -975,14 +994,33 @@ Playlist::split_region (Region& region, jack_nframes_t playlist_position)
 	before = playlist_position - region.position();
 	after = region.length() - before;
 	
+	
 	_session.region_name (before_name, region.name(), false);
 	left = createRegion (region, 0, before, before_name, region.layer(), Region::Flag (region.flags()|Region::LeftOfSplit));
 
 	_session.region_name (after_name, region.name(), false);
 	right = createRegion (region, before, after, after_name, region.layer(), Region::Flag (region.flags()|Region::RightOfSplit));
-	
+
 	add_region_internal (left, region.position(), true);
 	add_region_internal (right, region.position() + before);
+	
+	uint64_t orig_layer_op = region.last_layer_op();
+	for (RegionList::iterator i = regions.begin(); i != regions.end(); ++i) {
+		if ((*i)->last_layer_op() > orig_layer_op) {
+			(*i)->set_last_layer_op( (*i)->last_layer_op() + 1 );
+		}
+	}
+	
+	left->set_last_layer_op ( orig_layer_op );
+	right->set_last_layer_op ( orig_layer_op + 1);
+
+	layer_op_counter++;
+
+	finalize_split_region (&region, left, right);
+	
+	if (remove_region_internal (&region, true)) {
+		return;
+	}
 
 	maybe_save_state (_("split"));
 }
@@ -1328,9 +1366,13 @@ Playlist::set_state (const XMLNode& node)
 
 			add_region (*region, region->position(), 1.0, false);
 
+			// So that layer_op ordering doesn't get screwed up
+			region->set_last_layer_op( region->layer());
+
 		} 			
 	}
 
+	
  	/* update dependents, which was not done during add_region_internal 
 	   due to in_set_state being true 
 	*/
@@ -1338,7 +1380,7 @@ Playlist::set_state (const XMLNode& node)
 	for (RegionList::iterator r = regions.begin(); r != regions.end(); ++r) {
 		check_dependents (**r, false);
 	}
-
+	
 	in_set_state = false;
 
 	return 0;
