@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: session.cc,v 1.256 2006/02/13 00:25:00 essej Exp $
+    $Id: session.cc,v 1.257 2006/03/29 20:41:23 essej Exp $
 */
 
 #include <algorithm>
@@ -1253,7 +1253,7 @@ Session::enable_record ()
 }
 
 void
-Session::disable_record ()
+Session::disable_record (bool rt_context)
 {
 	if (atomic_read (&_record_status) != Disabled) {
 		atomic_set (&_record_status, Disabled);
@@ -1275,8 +1275,10 @@ Session::disable_record ()
 		}
 		
 		RecordDisabled ();
-		remove_pending_capture_state ();
 
+		if (!rt_context) {
+			remove_pending_capture_state ();
+		}
 	}
 }
 
