@@ -15,7 +15,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-  $Id: session_midi.cc,v 1.58 2006/01/12 18:18:14 persigmond Exp $
+  $Id: session_midi.cc,v 1.59 2006/03/29 20:41:24 essej Exp $
 */
 
 #include <string>
@@ -636,7 +636,7 @@ void
 Session::mmc_record_exit (MIDI::MachineControl &mmc)
 {
 	if (mmc_control) {
-		disable_record ();
+		disable_record (false);
 	}
 }
 
