@@ -15,7 +15,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
     
-  $Id: session_state.cc,v 1.157 2006/02/17 04:48:46 essej Exp $
+  $Id: session_state.cc,v 1.158 2006/03/29 20:41:24 essej Exp $
 */
 
 #include <algorithm>
@@ -1273,9 +1273,9 @@ Session::get_template()
 	   sources in their state node. 
 	*/
 	
-	disable_record ();
+	disable_record (false);
 
-	cerr << "STart get template\n";
+	//cerr << "Start get template\n";
 	return state(false);
 }
 
