@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: session_transport.cc,v 1.103 2006/01/31 05:24:08 essej Exp $
+    $Id: session_transport.cc,v 1.104 2006/03/29 20:41:24 essej Exp $
 */
 
 #include <cmath>
@@ -189,7 +189,7 @@ Session::realtime_stop (bool abort)
 	_clear_event_type (Event::RangeStop);
 	_clear_event_type (Event::RangeLocate);
 
-	disable_record ();
+	disable_record (true);
 
 	reset_slave_state ();
 		
@@ -379,7 +379,7 @@ Session::non_realtime_stop (bool abort)
 	}
 #endif
 
-	last_stop_frame = _transport_frame;
+       last_stop_frame = _transport_frame;
 
 	send_full_time_code ();
 	deliver_mmc (MIDI::MachineControl::cmdStop, 0);
@@ -395,6 +395,10 @@ Session::non_realtime_stop (bool abort)
 		save_state ("", true);
 	}
 
+	/* always try to get rid of this */
+
+	remove_pending_capture_state ();
+
 	/* save the current state of things if appropriate */
 	
 	if (did_record) {
@@ -825,7 +829,7 @@ Session::start_transport ()
 		break;
 
 	case Recording:
-		disable_record ();
+		disable_record (false);
 		break;
 
 	default:
